@@ -8,16 +8,20 @@ using SciMLBase: SciMLBase, NonlinearProblem, ReturnCode
 
 function SciMLBase.__solve(
         prob::NonlinearProblem, alg::SpeedMappingJL, args...;
-        abstol = nothing, maxiters = 1000, alias_u0::Bool = false,
+        abstol = nothing, maxiters = 1000, alias = SciMLBase.NonlinearAliasSpecifier(alias_u0 = false),
         maxtime = nothing, store_trace::Val = Val(false),
         termination_condition = nothing, kwargs...
-)
+    )
+    if haskey(kwargs, :alias_u0)
+        alias = SciMLBase.NonlinearAliasSpecifier(alias_u0 = kwargs[:alias_u0])
+    end
+    alias_u0 = alias.alias_u0
     NonlinearSolveBase.assert_extension_supported_termination_condition(
         termination_condition, alg
     )
 
     m!, u,
-    resid = NonlinearSolveBase.construct_extension_function_wrapper(
+        resid = NonlinearSolveBase.construct_extension_function_wrapper(
         prob; alias_u0, make_fixed_point = Val(true)
     )
     tol = NonlinearSolveBase.get_tolerance(abstol, eltype(u))
@@ -25,8 +29,10 @@ function SciMLBase.__solve(
     time_limit = ifelse(maxtime === nothing, 1000, maxtime)
 
     sol = speedmapping(
-        u; m!, tol, Lp = Inf, maps_limit = maxiters, alg.orders,
-        alg.check_obj, store_info = store_trace isa Val{true}, alg.σ_min, alg.stabilize,
+        u; m!, abstol = tol, pnorm = Inf, maps_limit = maxiters,
+        orders = Tuple(alg.orders),
+        initial_learning_rate = alg.σ_min == 0.0 ? 1.0 : alg.σ_min,
+        store_trace = store_trace isa Val{true},
         time_limit
     )
     res = prob.u0 isa Number ? first(sol.minimizer) : sol.minimizer
@@ -35,7 +41,7 @@ function SciMLBase.__solve(
     return SciMLBase.build_solution(
         prob, alg, res, resid;
         original = sol, stats = SciMLBase.NLStats(sol.maps, 0, 0, 0, sol.maps),
-        retcode = ifelse(sol.converged, ReturnCode.Success, ReturnCode.Failure)
+        retcode = ifelse(sol.status == :first_order, ReturnCode.Success, ReturnCode.Failure)
     )
 end
 
