@@ -3,7 +3,6 @@ module NonlinearSolve
 using ConcreteStructs: @concrete
 using Reexport: @reexport
 using PrecompileTools: @compile_workload, @setup_workload
-using FastClosures: @closure
 
 using ADTypes: ADTypes
 using ArrayInterface: ArrayInterface
@@ -11,17 +10,17 @@ using CommonSolve: CommonSolve, init, solve, solve!
 using LinearAlgebra: LinearAlgebra
 using LineSearch: BackTracking
 using NonlinearSolveBase: NonlinearSolveBase, AbstractNonlinearSolveAlgorithm,
-                          NonlinearSolvePolyAlgorithm, pickchunksize
+    NonlinearSolvePolyAlgorithm, pickchunksize, NonlinearVerbosity
 
 using SciMLBase: SciMLBase, ReturnCode, AbstractNonlinearProblem,
-                 NonlinearFunction,
-                 NonlinearProblem, NonlinearLeastSquaresProblem, NoSpecialize
+    NonlinearFunction,
+    NonlinearProblem, NonlinearLeastSquaresProblem, NoSpecialize
 using SymbolicIndexingInterface: SymbolicIndexingInterface
 using StaticArraysCore: StaticArray
 
 # Default Algorithm
 using NonlinearSolveFirstOrder: NewtonRaphson, TrustRegion, LevenbergMarquardt, GaussNewton,
-                                RUS, RobustMultiNewton
+    RUS, RobustMultiNewton
 using NonlinearSolveQuasiNewton: Broyden, Klement
 using SimpleNonlinearSolve: SimpleBroyden, SimpleKlement
 
@@ -51,7 +50,7 @@ include("forward_diff.jl")
     nonlinear_functions = (
         (NonlinearFunction{false, NoSpecialize}((u, p) -> u .* u .- p), 0.1),
         (NonlinearFunction{false, NoSpecialize}((u, p) -> u .* u .- p), [0.1]),
-        (NonlinearFunction{true, NoSpecialize}((du, u, p) -> du .= u .* u .- p), [0.1])
+        (NonlinearFunction{true, NoSpecialize}((du, u, p) -> du .= u .* u .- p), [0.1]),
     )
 
     nonlinear_problems = NonlinearProblem[]
@@ -62,22 +61,25 @@ include("forward_diff.jl")
     nonlinear_functions = (
         (NonlinearFunction{false, NoSpecialize}((u, p) -> (u .^ 2 .- p)[1:1]), [0.1, 0.0]),
         (
-            NonlinearFunction{false, NoSpecialize}((
-                u, p) -> vcat(u .* u .- p, u .* u .- p)),
-            [0.1, 0.1]
+            NonlinearFunction{false, NoSpecialize}(
+                (
+                    u, p,
+                ) -> vcat(u .* u .- p, u .* u .- p)
+            ),
+            [0.1, 0.1],
         ),
         (
             NonlinearFunction{true, NoSpecialize}(
                 (du, u, p) -> du[1] = u[1] * u[1] - p, resid_prototype = zeros(1)
             ),
-            [0.1, 0.0]
+            [0.1, 0.0],
         ),
         (
             NonlinearFunction{true, NoSpecialize}(
                 (du, u, p) -> du .= vcat(u .* u .- p, u .* u .- p), resid_prototype = zeros(4)
             ),
-            [0.1, 0.1]
-        )
+            [0.1, 0.1],
+        ),
     )
 
     nlls_problems = NonlinearLeastSquaresProblem[]
@@ -85,18 +87,17 @@ include("forward_diff.jl")
         push!(nlls_problems, NonlinearLeastSquaresProblem(fn, u0, 2.0))
     end
 
+    nlp_algs = [NewtonRaphson(), TrustRegion(), LevenbergMarquardt()]
+    nlls_algs = [GaussNewton(), TrustRegion(), LevenbergMarquardt()]
+
     @compile_workload begin
         @sync begin
-            for prob in nonlinear_problems
-                Threads.@spawn CommonSolve.solve(
-                    prob, nothing; abstol = 1e-2, verbose = false
-                )
+            for prob in nonlinear_problems, alg in nlp_algs
+                Threads.@spawn CommonSolve.solve(prob, alg; abstol = 1.0e-2, verbose = NonlinearVerbosity())
             end
 
-            for prob in nlls_problems
-                Threads.@spawn CommonSolve.solve(
-                    prob, nothing; abstol = 1e-2, verbose = false
-                )
+            for prob in nlls_problems, alg in nlls_algs
+                Threads.@spawn CommonSolve.solve(prob, alg; abstol = 1.0e-2, verbose = NonlinearVerbosity())
             end
         end
     end
@@ -105,7 +106,7 @@ end
 # Rexexports
 @reexport using SciMLBase, NonlinearSolveBase, LineSearch, ADTypes
 @reexport using NonlinearSolveFirstOrder, NonlinearSolveSpectralMethods,
-                NonlinearSolveQuasiNewton, SimpleNonlinearSolve, BracketingNonlinearSolve
+    NonlinearSolveQuasiNewton, SimpleNonlinearSolve, BracketingNonlinearSolve
 @reexport using LinearSolve
 
 # Poly Algorithms
@@ -113,7 +114,7 @@ export NonlinearSolvePolyAlgorithm, FastShortcutNonlinearPolyalg, FastShortcutNL
 
 # Extension Algorithms
 export LeastSquaresOptimJL, FastLevenbergMarquardtJL, NLsolveJL, NLSolversJL,
-       FixedPointAccelerationJL, SpeedMappingJL, SIAMFANLEquationsJL
+    FixedPointAccelerationJL, SpeedMappingJL, SIAMFANLEquationsJL
 export PETScSNES, CMINPACK
 
 end
