@@ -82,10 +82,10 @@ see the documentation for `FastLevenbergMarquardt.jl`.
 end
 
 function FastLevenbergMarquardtJL(
-        linsolve::Symbol = :cholesky; factor = 1e-6, factoraccept = 13.0,
-        factorreject = 3.0, factorupdate = :marquardt, minscale = 1e-12,
-        maxscale = 1e16, minfactor = 1e-28, maxfactor = 1e32, autodiff = nothing
-)
+        linsolve::Symbol = :cholesky; factor = 1.0e-6, factoraccept = 13.0,
+        factorreject = 3.0, factorupdate = :marquardt, minscale = 1.0e-12,
+        maxscale = 1.0e16, minfactor = 1.0e-28, maxfactor = 1.0e32, autodiff = nothing
+    )
     @assert linsolve in (:qr, :cholesky)
     @assert factorupdate in (:marquardt, :nielson)
 
@@ -223,7 +223,7 @@ end
 function NLsolveJL(;
         method = :trust_region, autodiff = :central, linesearch = missing, beta = 1.0,
         linsolve = (x, A, b) -> copyto!(x, A \ b), factor = 1.0, autoscale = true, m = 10
-)
+    )
     if Base.get_extension(@__MODULE__, :NonlinearSolveNLsolveExt) === nothing
         error("`NLsolveJL` requires `NLsolve.jl` to be loaded")
     end
@@ -307,7 +307,7 @@ end
 function SpeedMappingJL(;
         σ_min = 0.0, stabilize::Bool = false, check_obj::Bool = false,
         orders::Vector{Int} = [3, 3, 2]
-)
+    )
     if Base.get_extension(@__MODULE__, :NonlinearSolveSpeedMappingExt) === nothing
         error("`SpeedMappingJL` requires `SpeedMapping.jl` to be loaded")
     end
@@ -356,7 +356,7 @@ end
 function FixedPointAccelerationJL(;
         algorithm = :Anderson, m = missing, condition_number_threshold = missing,
         extrapolation_period = missing, replace_invalids = :NoAction, dampening = 1.0
-)
+    )
     if Base.get_extension(@__MODULE__, :NonlinearSolveFixedPointAccelerationExt) === nothing
         error("`FixedPointAccelerationJL` requires `FixedPointAcceleration.jl` to be loaded")
     end
@@ -365,14 +365,14 @@ function FixedPointAccelerationJL(;
     @assert replace_invalids in (:ReplaceInvalids, :ReplaceVector, :NoAction)
 
     if algorithm !== :Anderson
-        @assert condition_number_threshold===missing "`condition_number_threshold` is only valid for Anderson acceleration"
-        @assert m===missing "`m` is only valid for Anderson acceleration"
+        @assert condition_number_threshold === missing "`condition_number_threshold` is only valid for Anderson acceleration"
+        @assert m === missing "`m` is only valid for Anderson acceleration"
     end
-    condition_number_threshold === missing && (condition_number_threshold = 1e3)
+    condition_number_threshold === missing && (condition_number_threshold = 1.0e3)
     m === missing && (m = 10)
 
     if algorithm !== :MPE && algorithm !== :RRE && algorithm !== :VEA && algorithm !== :SEA
-        @assert extrapolation_period===missing "`extrapolation_period` is only valid for MPE, RRE, VEA and SEA"
+        @assert extrapolation_period === missing "`extrapolation_period` is only valid for MPE, RRE, VEA and SEA"
     end
     if extrapolation_period === missing
         extrapolation_period = algorithm === :SEA || algorithm === :VEA ? 6 : 7
@@ -427,9 +427,9 @@ end
 end
 
 function SIAMFANLEquationsJL(;
-        method = :newton, delta = 1e-3, linsolve = nothing, m = 0, beta = 1.0,
+        method = :newton, delta = 1.0e-3, linsolve = nothing, m = 0, beta = 1.0,
         autodiff = missing
-)
+    )
     if Base.get_extension(@__MODULE__, :NonlinearSolveSIAMFANLEquationsExt) === nothing
         error("`SIAMFANLEquationsJL` requires `SIAMFANLEquations.jl` to be loaded")
     end
