@@ -1,25 +1,25 @@
 const EXTENSION_SOLVER_TYPES = [
     LeastSquaresOptimJL, FastLevenbergMarquardtJL, NLsolveJL, NLSolversJL,
     SpeedMappingJL, FixedPointAccelerationJL, SIAMFANLEquationsJL,
-    CMINPACK, PETScSNES
+    CMINPACK, PETScSNES,
 ]
 
 const DualNonlinearProblem = NonlinearProblem{
     <:Union{Number, <:AbstractArray}, iip,
-    <:Union{<:Dual{T, V, P}, <:AbstractArray{<:Dual{T, V, P}}}
+    <:Union{<:Dual{T, V, P}, <:AbstractArray{<:Dual{T, V, P}}},
 } where {iip, T, V, P}
 const DualNonlinearLeastSquaresProblem = NonlinearLeastSquaresProblem{
     <:Union{Number, <:AbstractArray}, iip,
-    <:Union{<:Dual{T, V, P}, <:AbstractArray{<:Dual{T, V, P}}}
+    <:Union{<:Dual{T, V, P}, <:AbstractArray{<:Dual{T, V, P}}},
 } where {iip, T, V, P}
 const DualAbstractNonlinearProblem = Union{
-    DualNonlinearProblem, DualNonlinearLeastSquaresProblem
+    DualNonlinearProblem, DualNonlinearLeastSquaresProblem,
 }
 
 for algType in EXTENSION_SOLVER_TYPES
     @eval function SciMLBase.__init(
             prob::DualAbstractNonlinearProblem, alg::$(algType), args...; kwargs...
-    )
+        )
         p = NonlinearSolveBase.nodual_value(prob.p)
         newprob = SciMLBase.remake(prob; u0 = NonlinearSolveBase.nodual_value(prob.u0), p)
         cache = init(newprob, alg, args...; kwargs...)
@@ -32,9 +32,9 @@ end
 for algType in EXTENSION_SOLVER_TYPES
     @eval function SciMLBase.__solve(
             prob::DualAbstractNonlinearProblem, alg::$(algType), args...; kwargs...
-    )
+        )
         sol,
-        partials = NonlinearSolveBase.nonlinearsolve_forwarddiff_solve(
+            partials = NonlinearSolveBase.nonlinearsolve_forwarddiff_solve(
             prob, alg, args...; kwargs...
         )
         dual_soln = NonlinearSolveBase.nonlinearsolve_dual_solution(sol.u, partials, prob.p)
