@@ -1,4 +1,4 @@
-@testitem "Modeling Toolkit Cache Indexing" tags=[:downstream] begin
+@testitem "Modeling Toolkit Cache Indexing" tags = [:downstream] begin
     using ModelingToolkit
     using ModelingToolkit: t_nounits as t
     using SymbolicIndexingInterface
@@ -13,11 +13,13 @@
     nlprob = NonlinearProblem(nlsys, [X => 1.0], [p => 2.0, d => 3.0])
 
     @testset "$integtype" for (alg, integtype) in [
-        (NewtonRaphson(), NonlinearSolveFirstOrder.GeneralizedFirstOrderAlgorithmCache),
-        (FastShortcutNonlinearPolyalg(),
-            NonlinearSolveBase.NonlinearSolvePolyAlgorithmCache),
-        (SimpleNewtonRaphson(), NonlinearSolveBase.NonlinearSolveNoInitCache)
-    ]
+            (NewtonRaphson(), NonlinearSolveFirstOrder.GeneralizedFirstOrderAlgorithmCache),
+            (
+                FastShortcutNonlinearPolyalg(),
+                NonlinearSolveBase.NonlinearSolvePolyAlgorithmCache,
+            ),
+            (SimpleNewtonRaphson(), NonlinearSolveBase.NonlinearSolveNoInitCache),
+        ]
         nint = init(nlprob, alg)
         @test nint isa integtype
 
