@@ -4,39 +4,39 @@ include("../../common/common_nlls_testing.jl")
 
 end
 
-@testitem "LeastSquaresOptim.jl" setup=[WrapperNLLSSetup] tags=[:wrappers] begin
+@testitem "LeastSquaresOptim.jl" setup = [WrapperNLLSSetup] tags = [:wrappers] begin
     import LeastSquaresOptim
 
-    nlls_problems=[prob_oop, prob_iip]
+    nlls_problems = [prob_oop, prob_iip]
 
-    solvers=[]
+    solvers = []
     for alg in (:lm, :dogleg),
-        autodiff in (nothing, AutoForwardDiff(), AutoFiniteDiff(), :central, :forward)
+            autodiff in (nothing, AutoForwardDiff(), AutoFiniteDiff(), :central, :forward)
 
         push!(solvers, LeastSquaresOptimJL(alg; autodiff))
     end
 
     for prob in nlls_problems, solver in solvers
 
-        sol=solve(prob, solver; maxiters = 10000, abstol = 1e-8)
+        sol = solve(prob, solver; maxiters = 10000, abstol = 1.0e-8)
         @test SciMLBase.successful_retcode(sol)
-        @test maximum(abs, sol.resid) < 1e-6
+        @test maximum(abs, sol.resid) < 1.0e-6
     end
 end
 
-@testitem "FastLevenbergMarquardt.jl + CMINPACK: Jacobian Provided" setup=[WrapperNLLSSetup] tags=[:wrappers] begin
+@testitem "FastLevenbergMarquardt.jl + CMINPACK: Jacobian Provided" setup = [WrapperNLLSSetup] tags = [:wrappers] begin
     import FastLevenbergMarquardt, MINPACK
     using ForwardDiff
 
     function jac!(J, θ, p)
-        resid=zeros(length(p))
-        ForwardDiff.jacobian!(J, (resid, θ)->loss_function(resid, θ, p), resid, θ)
+        resid = zeros(length(p))
+        ForwardDiff.jacobian!(J, (resid, θ) -> loss_function(resid, θ, p), resid, θ)
         return J
     end
 
-    jac(θ, p)=ForwardDiff.jacobian(θ->loss_function(θ, p), θ)
+    jac(θ, p) = ForwardDiff.jacobian(θ -> loss_function(θ, p), θ)
 
-    probs=[
+    probs = [
         NonlinearLeastSquaresProblem(
             NonlinearFunction{true}(
                 loss_function; resid_prototype = zero(y_target), jac = jac!
@@ -51,23 +51,23 @@ end
         ),
         NonlinearLeastSquaresProblem(
             NonlinearFunction{false}(loss_function; jac), θ_init, x
-        )
+        ),
     ]
 
-    solvers=Any[FastLevenbergMarquardtJL(linsolve) for linsolve in (:cholesky, :qr)]
+    solvers = Any[FastLevenbergMarquardtJL(linsolve) for linsolve in (:cholesky, :qr)]
     Sys.isapple()||push!(solvers, CMINPACK())
 
     for solver in solvers, prob in probs
 
-        sol=solve(prob, solver; maxiters = 10000, abstol = 1e-8)
-        @test maximum(abs, sol.resid) < 1e-6
+        sol = solve(prob, solver; maxiters = 10000, abstol = 1.0e-8)
+        @test maximum(abs, sol.resid) < 1.0e-6
     end
 end
 
-@testitem "FastLevenbergMarquardt.jl + CMINPACK: Jacobian Not Provided" setup=[WrapperNLLSSetup] tags=[:wrappers] begin
+@testitem "FastLevenbergMarquardt.jl + CMINPACK: Jacobian Not Provided" setup = [WrapperNLLSSetup] tags = [:wrappers] begin
     import FastLevenbergMarquardt, MINPACK
 
-    probs=[
+    probs = [
         NonlinearLeastSquaresProblem(
             NonlinearFunction{true}(loss_function; resid_prototype = zero(y_target)),
             θ_init, x
@@ -76,12 +76,12 @@ end
             NonlinearFunction{false}(loss_function; resid_prototype = zero(y_target)),
             θ_init, x
         ),
-        NonlinearLeastSquaresProblem(NonlinearFunction{false}(loss_function), θ_init, x)
+        NonlinearLeastSquaresProblem(NonlinearFunction{false}(loss_function), θ_init, x),
     ]
 
-    solvers=[]
+    solvers = []
     for linsolve in (:cholesky, :qr),
-        autodiff in (nothing, AutoForwardDiff(), AutoFiniteDiff())
+            autodiff in (nothing, AutoForwardDiff(), AutoFiniteDiff())
 
         push!(solvers, FastLevenbergMarquardtJL(linsolve; autodiff))
     end
@@ -93,26 +93,26 @@ end
 
     for solver in solvers, prob in probs
 
-        sol=solve(prob, solver; maxiters = 10000, abstol = 1e-8)
-        @test maximum(abs, sol.resid) < 1e-6
+        sol = solve(prob, solver; maxiters = 10000, abstol = 1.0e-8)
+        @test maximum(abs, sol.resid) < 1.0e-6
     end
 end
 
-@testitem "FastLevenbergMarquardt.jl + StaticArrays" setup=[WrapperNLLSSetup] tags=[:wrappers] begin
+@testitem "FastLevenbergMarquardt.jl + StaticArrays" setup = [WrapperNLLSSetup] tags = [:wrappers] begin
     using StaticArrays, FastLevenbergMarquardt
 
-    x_sa=SA[-1.0, -0.5, 0.0, 0.5, 1.0]
+    x_sa = SA[-1.0, -0.5, 0.0, 0.5, 1.0]
 
-    const y_target_sa=true_function(x_sa, θ_true)
+    const y_target_sa = true_function(x_sa, θ_true)
 
     function loss_function_sa(θ, p)
-        ŷ=true_function(p, θ)
+        ŷ = true_function(p, θ)
         return ŷ .- y_target_sa
     end
 
-    θ_init_sa=SVector{4}(θ_init)
-    prob_sa=NonlinearLeastSquaresProblem{false}(loss_function_sa, θ_init_sa, x)
+    θ_init_sa = SVector{4}(θ_init)
+    prob_sa = NonlinearLeastSquaresProblem{false}(loss_function_sa, θ_init_sa, x)
 
-    sol=solve(prob_sa, FastLevenbergMarquardtJL())
-    @test maximum(abs, sol.resid) < 1e-6
+    sol = solve(prob_sa, FastLevenbergMarquardtJL())
+    @test maximum(abs, sol.resid) < 1.0e-6
 end
